@@ -22,7 +22,7 @@
 #include <NetworkManagerQt/Settings>
 #include <NetworkManagerQt/Utils>
 
-#include <QCoroCore>
+#include <QCoroTask>
 
 class PLASMANM_INTERNAL_EXPORT Handler : public QObject
 {
@@ -34,6 +34,7 @@ public:
     ~Handler() override;
 
     Q_PROPERTY(bool hotspotSupported READ hotspotSupported NOTIFY hotspotSupportedChanged)
+    Q_PROPERTY(bool hotspotActive READ hotspotActive NOTIFY hotspotActiveChanged)
 
     // Not scientifically correct, but a good estimation of whether a scanning is currently in progress.
     Q_PROPERTY(bool scanning READ isScanning NOTIFY scanningChanged)
@@ -44,6 +45,11 @@ public:
         return m_hotspotSupported;
     }
 
+    bool hotspotActive() const
+    {
+        return m_hotspotActive;
+    }
+
     bool isScanning() const
     {
         return m_ongoingScansCount != 0;
@@ -90,7 +96,7 @@ public Q_SLOTS:
      * Adds a new connection
      * @map - NMVariantMapMap with connection settings
      */
-    QCoro::Task<void> addConnection(const NMVariantMapMap &map);
+    QCoro::Task<> addConnection(const NMVariantMapMap &map);
 
     /**
      * Deactivates given connection
@@ -118,7 +124,7 @@ public Q_SLOTS:
      * @connection - connection which should be updated
      * @map - NMVariantMapMap with new connection settings
      */
-    QCoro::Task<void> updateConnection(NetworkManager::Connection::Ptr connection, const NMVariantMapMap &map);
+    QCoro::Task<> updateConnection(NetworkManager::Connection::Ptr connection, const NMVariantMapMap &map);
     void requestScan(const QString &interface = QString());
 
     void createHotspot();
@@ -127,27 +133,27 @@ public Q_SLOTS:
 private Q_SLOTS:
     void secretAgentError(const QString &connectionPath, const QString &message);
     void primaryConnectionTypeChanged(NetworkManager::ConnectionSettings::ConnectionType type);
+    void wirelessEnabledChanged(bool wirelessEnabled);
     void unlockRequiredChanged(MMModemLock modemLock);
-    void slotRequestWifiCode(QDBusPendingCallWatcher *watcher);
 
 Q_SIGNALS:
     void connectionActivationFailed(const QString &connectionPath, const QString &message);
-    void hotspotCreated();
-    void hotspotDisabled();
     void hotspotSupportedChanged(bool hotspotSupported);
+    void hotspotActiveChanged(bool hotspotActive);
     void scanningChanged();
-    void wifiCodeReceived(const QString &data, const QString &ssid);
+    void wifiCodeReceived(const QString &data, const QString &ssid, const QString &password = QString());
 
 private:
-    QCoro::Task<void> addAndActivateConnectionDBus(const NMVariantMapMap &map, const QString &device, const QString &specificObject);
-    QCoro::Task<void> activateConnectionInternal(const QString &connection, const QString &device, const QString &specificParameter);
-    QCoro::Task<void> addAndActivateConnectionInternal(const QString &device, const QString &specificParameter, const QString &password = QString());
-    QCoro::Task<void> deactivateConnectionInternal(const QString &connection, const QString &device);
-    QCoro::Task<void> removeConnectionInternal(const QString &connection);
-    QCoro::Task<void> requestScanInternal(const QString &interface = QString());
-    QCoro::Task<void> createHotspotInternal();
+    QCoro::Task<> addAndActivateConnectionDBus(const NMVariantMapMap &map, const QString &device, const QString &specificObject);
+    QCoro::Task<> activateConnectionInternal(const QString &connection, const QString &device, const QString &specificParameter);
+    QCoro::Task<> addAndActivateConnectionInternal(const QString &device, const QString &specificParameter, const QString &password = QString());
+    QCoro::Task<> deactivateConnectionInternal(const QString &connection, const QString &device);
+    QCoro::Task<> removeConnectionInternal(const QString &connection);
+    QCoro::Task<> requestScanInternal(const QString &interface = QString());
+    QCoro::Task<> createHotspotInternal();
 
     bool m_hotspotSupported;
+    bool m_hotspotActive;
     bool m_tmpWirelessEnabled;
     bool m_tmpWwanEnabled;
     QString m_tmpConnectionPath;
@@ -158,13 +164,14 @@ private:
     QMap<QString, QTimer *> m_wirelessScanRetryTimer;
     short m_ongoingScansCount = 0;
 
-    QCoro::Task<void> enableBluetooth(bool enable);
+    QCoro::Task<> enableBluetooth(bool enable);
     void scanRequestFailed(const QString &interface);
     bool checkRequestScanRateLimit(const NetworkManager::WirelessDevice::Ptr &wifiDevice);
     bool checkHotspotSupported();
     void scheduleRequestScan(const QString &interface, int timeout);
     void incrementScansCount();
     void decrementScansCount();
+    void onWiFiCodeResponse(QDBusPendingCallWatcher *watcher, QString &&ret, const QString &ssid, NetworkManager::WirelessSecurityType securityType);
 
     QPointer<QDBusPendingCallWatcher> m_requestWifiCodeWatcher;
 };
